@@ -15,7 +15,7 @@ except ImportError: #python 3 zip is same as izip
     izip = zip
 
 from ..aid.sixing import *
-from .globaling import AUX, MOOT, INDENT_ADD, ScheduleNames
+from .globaling import AUX, MOOT, INDENT_ADD, ScheduleNames, TRANSIT, ActionSubContextNames
 from ..aid.odicting import odict
 
 from ..aid.classing import metaclassify, nonStringIterable
@@ -40,9 +40,10 @@ class Act(object):
     def __init__(self, frame=None, context=None, act=None, actor=None,
                  registrar=None, inits=None, ioinits=None, parms=None,
                  prerefs=None, human='', count=0, **kwa ):
-        """ Initialization method for instance.
+        """
+        Initialization method for instance.
 
-            Attributes:
+        Attributes:
             .frame = ref to Frame holding this Act
             .context = name string of actioning context set when added to frame
             .act = ref to super Act if self is embedded in another Act such as Need
@@ -55,6 +56,13 @@ class Act(object):
             .prerefs = dictionary of init, ioinit, and parm refs to resolve
             .human = human friendly version of action declaration
             .count = line count in floscript of action declaration
+
+        Share path resolution
+            act.resolve aggregates ioinits from registry,  act.ioinits, and act.prerefs
+            act.resolve calls .actor._initio with ionits as parameters to get iois
+            then for each ioi act.resolve calls .resolvePath to get share or node
+            and then assigns share/node to to attribute/parameter of .actor
+
         """
         super(Act,self).__init__(**kwa) # in case of MRO
 
@@ -214,7 +222,7 @@ class Act(object):
             If the path name starts with a leading '.' dot then path name is
             fully reconciled and no contextual substitutions are to be applied.
 
-            If the path name begins with 'me' then the path is inode relative
+            If the path name begins with 'me' then the path is framer inode relative
 
             Otherwise make subsitutions in pathname strings that begin
             with 'framer.'
@@ -275,8 +283,12 @@ class Act(object):
                     framer = self.frame.framer
                     finode = framer.inode
                     if framer.main:  # aux framer so special meaning of main or mine
+                        mainer = framer.main.framer  # main frame's framer eg main framer
                         if finode == "main":  # replace finode with main framer inode
-                            finode = framer.main.framer.inode
+                            finode = mainer.inode
+                            while finode == "main" and mainer.main:  # inode is main and has a main frame
+                                mainer = mainer.main.framer # walk up mainer links
+                                finode = mainer.inode  # substitude main for mainer.inode
                         elif finode == "mine":  # don't prepend main framer inode
                             finode = ""
                         else:  # possibly prepend main framer inode if finode relative
@@ -285,6 +297,8 @@ class Act(object):
                             if not finode.startswith('.') and minode:  # prepend if relative
                                 finode = '.'.join([minode, finode])
                     finode = finode.rstrip('.')
+                    if not finode:  # empty finode so use default actor relative
+                        finode = "framer.me.frame.me.actor.me"
                     if finode:
                         finparts = finode.split('.')
                         if finparts:
@@ -568,7 +582,7 @@ class Actor(object):
         The default inode is  'framer.me.frame.me.actor.me.'
             This occurs if the framer inode (finode) is empty
                 (which occurs when the via clause is missing for the framer)
-            and the ioinit inode paramter passed in is also empty
+            and the ioinit inode parameter passed in is also empty
 
         When a via clause exists for the framer then finode is not empty
             so the default is not used
@@ -649,15 +663,19 @@ class Actor(object):
             raise ValueError("Nonstring inode arg '{0}'".format(inode))
 
         finode = ''  # inode of framer
-        if self._act.frame.framer:
+        if self._act.frame.framer: # framer has been assigned
             framer = self._act.frame.framer
             finode = framer.inode  # could be empty
             if framer.main:  # aux framer so special meaning of main or mine
+                mainer = framer.main.framer  # main frame's framer eg main framer
                 if finode == "main":  # replace finode with main framer inode
-                    finode = framer.main.framer.inode
+                    finode = mainer.inode
+                    while finode == "main" and mainer.main:  # inode is main and has a main frame
+                        mainer = mainer.main.framer # walk up mainer links
+                        finode = mainer.inode  # substitude main for mainer.inode
                 elif finode == "mine":  # don't prepend main framer inode
                     finode = ""  # effectively empty inode
-                else:  # possibly prepend main framer inode if finode relative
+                else:  # otherwise just prepend main framer inode if relative
                     minode = framer.main.framer.inode  # could be empty
                     minode = minode.rstrip('.')
                     if not finode.startswith('.') and minode:  # prepend if relative
@@ -666,6 +684,8 @@ class Actor(object):
         finode = finode.rstrip('.')
 
         if not inode.startswith('.') and finode:  # not absolute and finode so prepend
+            if inode.startswith('me.') or inode == 'me':
+                raise ValueError("Invalid inode '{0}', first part == 'me'".format(inode))
             inode = ".".join([finode, inode])
 
         if not inode:  # empty or missing use default actor relative
@@ -706,17 +726,20 @@ class Actor(object):
 
             if ipath:
                 if not ipath.startswith('.'): # full path is inode joined to ipath
-                    ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
+                    if not(ipath.startswith('me.') or ipath == 'me'):  # do not override inode
+                        ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
+                    # any paths starting with me with have the framer inode (finode) substituted
+                    # in actor.resolvePath later this allows override of doer inode appendix
             else: # empty ipath
                 ipath = '.'.join((inode.rstrip('.'), key))  # when ipath empty create default from key
 
-            if ipath.startswith('me.') or ipath == 'me':
-                raise ValueError("Invalid ipath '{0}', first part == 'me'".format(ipath))
+            #if ipath.startswith('me.') or ipath == 'me':
+            #    raise ValueError("Invalid ipath '{0}', first part == 'me'".format(ipath))
 
             ioi = odict(ipath=ipath, ival=ival, iown=iown)
             iois[key] = ioi
 
-        ioi = odict(ipath=inode)
+        ioi = odict(ipath=inode)  # create ioi for the inode
         iois['inode'] = ioi
 
         return iois # non-empty when _parametric
@@ -887,26 +910,38 @@ class Actor(object):
                                                      self._act.count)
 
 class Interrupter(Actor):
-    """Interrupter Actor Class
-       Interrupter is a base clase for all actor classes that interrupt normal precur
-       processing and result in a change in the frame or the frame processing.
+    """
+    Interrupter Actor Class
+    Interrupter is a base clase for all actor classes that interrupt normal precur
+    processing and result in a change in the frame or the frame processing.
 
-       This class must be subclassed. This is a convenience so can either use
-         isinstance to test
-
-       Specifically an Interrupter's action() method returns truthy when its action
-       interrupts the normal frame processing.
-
-       Examples are:
-       Transiters which interrupt by changing to a new frame
-       Suspenders which interrupt when the conditional aux condition is true and
-          further processing of the frame and sub frames is stopped
+    This class must be subclassed. This is a convenience so can either use
+      isinstance to test
 
+    Specifically an Interrupter's action() method returns truthy when its action
+    interrupts the normal frame processing.
 
+    Examples are:
+    Transiters which interrupt by changing to a new frame
+    Suspenders which interrupt when the conditional aux condition is true and
+       further processing of the frame and sub frames is stopped
     """
     def __init__(self,**kw ):
-        """Initialization method for instance. """
+        """
+        Initialization method for instance.
+
+        Inherited Attributes:
+            .name = name string for Actor variant in class Registry
+            .store = reference to shared data Store
+            ._act = reference to containing Act
+
+        Attributes:
+            ._tracts = list of references to transition acts for this Actor
+                transit sub-context of precur context during segue
+
+        """
         super(Interrupter,self).__init__(**kw)
+        self._tracts = []
 
 class Transiter(Interrupter):
     """Transiter Interrupter Class
@@ -953,8 +988,10 @@ class Transiter(Interrupter):
         parms['far'] = far
 
         for act in needs:
-            act.act = self._act
+            act.act = self._act  # so act.resolve can ref self._act.frame.framer
             act.resolve()
+            self._tracts.extend(act.actor._tracts)
+            del act.actor._tracts[:]
 
         return parms
 
@@ -979,11 +1016,11 @@ class Transiter(Interrupter):
         exits, enters, reexens = framing.Framer.ExEn(framer.actives, far)
 
         #check enters, if successful, perform transition
-        if not framer.checkEnter(enters):
+        if not framer.checkEnter(enters, exits):
             return None
 
         msg = "To: {0}<{1} at {2} Via: {3} ({4}) From: {5} after {6:0.3f}\n".format(
-            framer.name, far.human, framer.store.stamp, near.name, human,
+            framer.name, far.human, round(framer.store.stamp, 6), near.name, human,
             framer.human, framer.elapsed)
         console.terse(msg)
 
@@ -991,6 +1028,9 @@ class Transiter(Interrupter):
         console.profuse("     enters: {0}\n".format([frame.name for frame in enters]))
         console.profuse("     reexens: {0}\n".format([frame.name for frame in reexens]))
 
+        for act in self._tracts:  # transit sub-context of segue precur
+            act()
+
         framer.exit(exits) #exit uncommon frames in near outline reversed in place
         framer.rexit(reexens[:]) #make copy since reversed in place
         framer.renter(reexens)
@@ -1043,6 +1083,8 @@ class Suspender(Interrupter):
         for act in needs:
             act.act = self._act
             act.resolve()
+            self._tracts.extend(act.actor._tracts)
+            del act.actor._tracts[:]
 
         deActParms = odict(aux=aux)
         deAct = SideAct( actor=self,
@@ -1076,18 +1118,21 @@ class Suspender(Interrupter):
             # if aux.main is not None then it has not been released and so
             # we can't enter unless it is our act's frame
             if aux.main and (aux.main is not self._act.frame):
-                console.concise("    Invalid aux '{0}' in use "
-                        "by another frame '{1}'\n".format(aux.name, aux.main.name))
+                console.concise("    Invalid aux '{0}' in use by another frame"
+                        " '{1}'\n".format(aux.name, aux.main.name))
                 return None
 
             if not aux.checkStart(): #performs entry checks
                 return None
 
             msg = "To: {0} in {1}<{2} at {3} Via: {4} ({5}) From: {6} after {7:0.3f}\n".format(
-                aux.name, framer.name, main.headHuman, framer.store.stamp, main.name,
+                aux.name, framer.name, main.headHuman, round(framer.store.stamp, 6), main.name,
                 human, framer.human, framer.elapsed)
             console.terse(msg)
 
+            for act in self._tracts:  # transit sub-context of cond aux segue precur
+                act()
+
             if aux.original:
                 aux.main = main  #assign aux's main to this frame
             aux.enterAll() #starts at aux.first frame
@@ -1164,20 +1209,22 @@ class MarkerUpdate(Marker):
         Builder at parse time when it encounters an NeedUpdate,
         creates the mark in the share and creates the appropriate MarkerUpdate
     """
-    def action(self, share, frame, **kwa):
+    def action(self, share, marker, **kwa):
         """ Update mark in share
-            Where share is reference to share and frame is frame name key of mark in
+            Where share is reference to share and marker is unique name key of mark in
                 share.marks odict
             Updates mark.stamp
 
-            only one mark per frame per share is needed
+            only one mark per marker per share is needed
         """
         console.profuse("{0} mark {1} in {2} on {3}\n".format(
-            self.name, share.name, frame, 'update' ))
+            self.name, share.name, marker, 'update' ))
 
-        mark = share.marks.get(frame)
+        mark = share.marks.get(marker)
         if mark:
-            mark.stamp = self.store.stamp #stamp when marker runs
+            mark.stamp = self.store.stamp  # update stamp when marker runs
+            if self._act.context == ActionSubContextNames[TRANSIT]:  # transit satisfied
+                mark.used = mark.stamp
 
     def _expose(self):
         """   """
@@ -1194,20 +1241,20 @@ class MarkerChange(Marker):
         Builder at parse time when it encounters a NeedChange,
         creates the mark in the share and creates the appropriate marker
     """
-    def action(self, share, frame, **kwa):
+    def action(self, share, marker, **kwa):
         """ Update mark in share
-            Where share is reference to share and frame is frame name key of mark in
+            Where share is reference to share and marker is unique name key of mark in
                 share.marks odict
             Updates mark.data
 
-            only one mark per frame per share is needed
+            only one mark per marker per share is needed
         """
         console.profuse("{0} mark {1} in {2} on {3}\n".format(
-            self.name, share.name, frame, 'change' ))
+            self.name, share.name, marker, 'change' ))
 
-        mark = share.marks.get(frame)
+        mark = share.marks.get(marker)
         if mark:
-            mark.data = storing.Data(share.items())
+            mark.data = storing.Data(share.items())  # set date when marker runs
 
     def _expose(self):
         """   """
